# High Performance Distributed Config Manager

This project try to manage config for distributed servers.

[The source for this project is available here][https://github.com/zioniony/configpro].

Realtime config is cached in redis backend and persistant stored in database.

Server specific config stored in a file specific in .configpro under project home.

----

[packaging guide]: https://packaging.python.org
[distribution tutorial]: https://packaging.python.org/tutorials/packaging-projects/
[src]: https://github.com/zioniony/configpro
[rst]: http://docutils.sourceforge.net/rst.html
[md]: https://tools.ietf.org/html/rfc7764#section-3.5 "CommonMark variant"
[md use]: https://packaging.python.org/specifications/core-metadata/#description-content-type-optional
